cattr package
=============

Submodules
----------

cattr.converters module
-----------------------

.. automodule:: cattr.converters
    :members:
    :undoc-members:
    :show-inheritance:

cattr.disambiguators module
---------------------------

.. automodule:: cattr.disambiguators
    :members:
    :undoc-members:
    :show-inheritance:

cattr.function_dispatch module
------------------------------

.. automodule:: cattr.function_dispatch
    :members:
    :undoc-members:
    :show-inheritance:

cattr.metadata module
---------------------

.. automodule:: cattr.metadata
    :members:
    :undoc-members:
    :show-inheritance:

cattr.multistrategy_dispatch module
-----------------------------------

.. automodule:: cattr.multistrategy_dispatch
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cattr
    :members:
    :undoc-members:
    :show-inheritance:
